# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: base.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import timestamp_pb2 as google_dot_protobuf_dot_timestamp__pb2
from google.protobuf import any_pb2 as google_dot_protobuf_dot_any__pb2
from . import querys_pb2 as querys__pb2
from . import queues_pb2 as queues__pb2
from . import watch_pb2 as watch__pb2
from . import workitems_pb2 as workitems__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\nbase.proto\x12\x07openiap\x1a\x1fgoogle/protobuf/timestamp.proto\x1a\x19google/protobuf/any.proto\x1a\x0cquerys.proto\x1a\x0cqueues.proto\x1a\x0bwatch.proto\x1a\x0fworkitems.proto\"\xa5\x01\n\x08\x45nvelope\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\x10\n\x08priority\x18\x02 \x01(\x05\x12\x0b\n\x03seq\x18\x03 \x01(\x05\x12\n\n\x02id\x18\x04 \x01(\t\x12\x0b\n\x03rid\x18\x05 \x01(\t\x12\"\n\x04\x64\x61ta\x18\x06 \x01(\x0b\x32\x14.google.protobuf.Any\x12\x0b\n\x03jwt\x18\x07 \x01(\t\x12\x0f\n\x07traceid\x18\x08 \x01(\t\x12\x0e\n\x06spanid\x18\t \x01(\t\"\r\n\x0bPingRequest\"\x0e\n\x0cPingResponse\"=\n\rErrorResponse\x12\x0f\n\x07message\x18\x01 \x01(\t\x12\x0c\n\x04\x63ode\x18\x02 \x01(\x05\x12\r\n\x05stack\x18\x03 \x01(\t\"\"\n\x11GetElementRequest\x12\r\n\x05xpath\x18\x01 \x01(\t\"#\n\x12GetElementResponse\x12\r\n\x05xpath\x18\x01 \x01(\t\"/\n\x0f\x44ownloadRequest\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\"B\n\x10\x44ownloadResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\x10\n\x08mimetype\x18\x03 \x01(\t\"3\n\rUploadRequest\x12\x10\n\x08\x66ilename\x18\x01 \x01(\t\x12\x10\n\x08mimetype\x18\x02 \x01(\t\"|\n\x0eUploadResponse\x12\n\n\x02id\x18\x01 \x01(\t\x12\x10\n\x08\x66ilename\x18\x02 \x01(\t\x12\r\n\x05\x62ytes\x18\x03 \x01(\x05\x12\x0e\n\x06\x63hunks\x18\x04 \x01(\x05\x12\n\n\x02mb\x18\x05 \x01(\x02\x12\x13\n\x0b\x65lapsedTime\x18\x06 \x01(\x05\x12\x0c\n\x04mbps\x18\x07 \x01(\x02\"<\n\x0b\x42\x65ginStream\x12\x10\n\x08\x63hecksum\x18\x01 \x01(\t\x12\x1b\n\x04stat\x18\x02 \x01(\x0b\x32\r.openiap.Stat\"\x16\n\x06Stream\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\"\x0b\n\tEndStream\"\xa1\x02\n\x04Stat\x12\x13\n\x0b\x62irthtimeMs\x18\x01 \x01(\x02\x12\x0f\n\x07\x62lksize\x18\x02 \x01(\x05\x12\x0e\n\x06\x62locks\x18\x03 \x01(\x05\x12)\n\x05\x63time\x18\x04 \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07\x63timeMs\x18\x05 \x01(\x02\x12\x0b\n\x03\x64\x65v\x18\x06 \x01(\x05\x12\x0b\n\x03gid\x18\x07 \x01(\x05\x12\x0b\n\x03ino\x18\x08 \x01(\x05\x12\x0c\n\x04mode\x18\t \x01(\x05\x12)\n\x05mtime\x18\n \x01(\x0b\x32\x1a.google.protobuf.Timestamp\x12\x0f\n\x07mtimeMs\x18\x0b \x01(\x02\x12\r\n\x05nlink\x18\x0c \x01(\x05\x12\x0c\n\x04rdev\x18\r \x01(\x05\x12\x0c\n\x04size\x18\x0e \x01(\x05\x12\x0b\n\x03uid\x18\x0f \x01(\x05\"O\n\x14\x43ustomCommandRequest\x12\x0f\n\x07\x63ommand\x18\x01 \x01(\t\x12\n\n\x02id\x18\x02 \x01(\t\x12\x0c\n\x04name\x18\x03 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x04 \x01(\t\"\'\n\x15\x43ustomCommandResponse\x12\x0e\n\x06result\x18\x01 \x01(\t\"\x84\x01\n\rSigninRequest\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x10\n\x08password\x18\x02 \x01(\t\x12\x0b\n\x03jwt\x18\x03 \x01(\t\x12\x0c\n\x04ping\x18\x04 \x01(\x08\x12\x14\n\x0cvalidateonly\x18\x05 \x01(\x08\x12\r\n\x05\x61gent\x18\x06 \x01(\t\x12\x0f\n\x07version\x18\x07 \x01(\t\":\n\x0eSigninResponse\x12\x0b\n\x03jwt\x18\x01 \x01(\t\x12\x1b\n\x04user\x18\x02 \x01(\x0b\x32\r.openiap.User\"J\n\x0cRefreshToken\x12\x10\n\x08username\x18\x01 \x01(\t\x12\x0b\n\x03jwt\x18\x02 \x01(\t\x12\x1b\n\x04user\x18\x03 \x01(\x0b\x32\r.openiap.User\"!\n\x04Role\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\"`\n\x04User\x12\x0b\n\x03_id\x18\x01 \x01(\t\x12\x0c\n\x04name\x18\x02 \x01(\t\x12\x10\n\x08username\x18\x03 \x01(\t\x12\r\n\x05\x65mail\x18\x04 \x01(\t\x12\x1c\n\x05roles\x18\x05 \x03(\x0b\x32\r.openiap.Role2\x9b\x12\n\x0b\x46lowService\x12\x39\n\x0bSetupStream\x12\x11.openiap.Envelope\x1a\x11.openiap.Envelope\"\x00(\x01\x30\x01\x12\x39\n\x06Signin\x12\x16.openiap.SigninRequest\x1a\x17.openiap.SigninResponse\x12?\n\x08\x44ownload\x12\x18.openiap.DownloadRequest\x1a\x19.openiap.DownloadResponse\x12\x39\n\x06Upload\x12\x16.openiap.UploadRequest\x1a\x17.openiap.UploadResponse\x12N\n\rCustomCommand\x12\x1d.openiap.CustomCommandRequest\x1a\x1e.openiap.CustomCommandResponse\x12T\n\x0fListCollections\x12\x1f.openiap.ListCollectionsRequest\x1a .openiap.ListCollectionsResponse\x12Q\n\x0e\x44ropCollection\x12\x1e.openiap.DropCollectionRequest\x1a\x1f.openiap.DropCollectionResponse\x12\x36\n\x05Query\x12\x15.openiap.QueryRequest\x1a\x16.openiap.QueryResponse\x12]\n\x12GetDocumentVersion\x12\".openiap.GetDocumentVersionRequest\x1a#.openiap.GetDocumentVersionResponse\x12\x42\n\tAggregate\x12\x19.openiap.AggregateRequest\x1a\x1a.openiap.AggregateResponse\x12\x36\n\x05\x43ount\x12\x15.openiap.CountRequest\x1a\x16.openiap.CountResponse\x12\x42\n\tInsertOne\x12\x19.openiap.InsertOneRequest\x1a\x1a.openiap.InsertOneResponse\x12\x45\n\nInsertMany\x12\x1a.openiap.InsertManyRequest\x1a\x1b.openiap.InsertManyResponse\x12\x42\n\tUpdateOne\x12\x19.openiap.UpdateOneRequest\x1a\x1a.openiap.UpdateOneResponse\x12Q\n\x0eUpdateDocument\x12\x1e.openiap.UpdateDocumentRequest\x1a\x1f.openiap.UpdateDocumentResponse\x12Z\n\x11InsertOrUpdateOne\x12!.openiap.InsertOrUpdateOneRequest\x1a\".openiap.InsertOrUpdateOneResponse\x12]\n\x12InsertOrUpdateMany\x12\".openiap.InsertOrUpdateManyRequest\x1a#.openiap.InsertOrUpdateManyResponse\x12\x42\n\tDeleteOne\x12\x19.openiap.DeleteOneRequest\x1a\x1a.openiap.DeleteOneResponse\x12\x45\n\nDeleteMany\x12\x1a.openiap.DeleteManyRequest\x1a\x1b.openiap.DeleteManyResponse\x12N\n\rRegisterQueue\x12\x1d.openiap.RegisterQueueRequest\x1a\x1e.openiap.RegisterQueueResponse\x12W\n\x10RegisterExchange\x12 .openiap.RegisterExchangeRequest\x1a!.openiap.RegisterExchangeResponse\x12K\n\x0cQueueMessage\x12\x1c.openiap.QueueMessageRequest\x1a\x1d.openiap.QueueMessageResponse\x12T\n\x0fUnRegisterQueue\x12\x1f.openiap.UnRegisterQueueRequest\x1a .openiap.UnRegisterQueueResponse\x12\x36\n\x05Watch\x12\x15.openiap.WatchRequest\x1a\x16.openiap.WatchResponse\x12<\n\x07UnWatch\x12\x17.openiap.UnWatchRequest\x1a\x18.openiap.UnWatchResponse\x12K\n\x0cPushWorkitem\x12\x1c.openiap.PushWorkitemRequest\x1a\x1d.openiap.PushWorkitemResponse\x12N\n\rPushWorkitems\x12\x1d.openiap.PushWorkitemsRequest\x1a\x1e.openiap.PushWorkitemsResponse\x12Q\n\x0eUpdateWorkitem\x12\x1e.openiap.UpdateWorkitemRequest\x1a\x1f.openiap.UpdateWorkitemResponse\x12H\n\x0bPopWorkitem\x12\x1b.openiap.PopWorkitemRequest\x1a\x1c.openiap.PopWorkitemResponse\x12Q\n\x0e\x44\x65leteWorkitem\x12\x1e.openiap.DeleteWorkitemRequest\x1a\x1f.openiap.DeleteWorkitemResponse\x12W\n\x10\x41\x64\x64WorkItemQueue\x12 .openiap.AddWorkItemQueueRequest\x1a!.openiap.AddWorkItemQueueResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'base_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _ENVELOPE._serialized_start=142
  _ENVELOPE._serialized_end=307
  _PINGREQUEST._serialized_start=309
  _PINGREQUEST._serialized_end=322
  _PINGRESPONSE._serialized_start=324
  _PINGRESPONSE._serialized_end=338
  _ERRORRESPONSE._serialized_start=340
  _ERRORRESPONSE._serialized_end=401
  _GETELEMENTREQUEST._serialized_start=403
  _GETELEMENTREQUEST._serialized_end=437
  _GETELEMENTRESPONSE._serialized_start=439
  _GETELEMENTRESPONSE._serialized_end=474
  _DOWNLOADREQUEST._serialized_start=476
  _DOWNLOADREQUEST._serialized_end=523
  _DOWNLOADRESPONSE._serialized_start=525
  _DOWNLOADRESPONSE._serialized_end=591
  _UPLOADREQUEST._serialized_start=593
  _UPLOADREQUEST._serialized_end=644
  _UPLOADRESPONSE._serialized_start=646
  _UPLOADRESPONSE._serialized_end=770
  _BEGINSTREAM._serialized_start=772
  _BEGINSTREAM._serialized_end=832
  _STREAM._serialized_start=834
  _STREAM._serialized_end=856
  _ENDSTREAM._serialized_start=858
  _ENDSTREAM._serialized_end=869
  _STAT._serialized_start=872
  _STAT._serialized_end=1161
  _CUSTOMCOMMANDREQUEST._serialized_start=1163
  _CUSTOMCOMMANDREQUEST._serialized_end=1242
  _CUSTOMCOMMANDRESPONSE._serialized_start=1244
  _CUSTOMCOMMANDRESPONSE._serialized_end=1283
  _SIGNINREQUEST._serialized_start=1286
  _SIGNINREQUEST._serialized_end=1418
  _SIGNINRESPONSE._serialized_start=1420
  _SIGNINRESPONSE._serialized_end=1478
  _REFRESHTOKEN._serialized_start=1480
  _REFRESHTOKEN._serialized_end=1554
  _ROLE._serialized_start=1556
  _ROLE._serialized_end=1589
  _USER._serialized_start=1591
  _USER._serialized_end=1687
  _FLOWSERVICE._serialized_start=1690
  _FLOWSERVICE._serialized_end=4021
# @@protoc_insertion_point(module_scope)
