# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: queues.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0cqueues.proto\x12\x07openiap\")\n\x14RegisterQueueRequest\x12\x11\n\tqueuename\x18\x01 \x01(\t\"*\n\x15RegisterQueueResponse\x12\x11\n\tqueuename\x18\x01 \x01(\t\"h\n\x17RegisterExchangeRequest\x12\x14\n\x0c\x65xchangename\x18\x01 \x01(\t\x12\x11\n\talgorithm\x18\x02 \x01(\t\x12\x12\n\nroutingkey\x18\x03 \x01(\t\x12\x10\n\x08\x61\x64\x64queue\x18\x04 \x01(\x08\"-\n\x18RegisterExchangeResponse\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\x9c\x01\n\x13QueueMessageRequest\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\x12\x12\n\nstriptoken\x18\x07 \x01(\x08\"\x89\x01\n\x14QueueMessageResponse\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"\x7f\n\nQueueEvent\x12\x11\n\tqueuename\x18\x01 \x01(\t\x12\x15\n\rcorrelationId\x18\x02 \x01(\t\x12\x0f\n\x07replyto\x18\x03 \x01(\t\x12\x12\n\nroutingkey\x18\x04 \x01(\t\x12\x14\n\x0c\x65xchangename\x18\x05 \x01(\t\x12\x0c\n\x04\x64\x61ta\x18\x06 \x01(\t\"+\n\x16UnRegisterQueueRequest\x12\x11\n\tqueuename\x18\x01 \x01(\t\"\x19\n\x17UnRegisterQueueResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'queues_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _REGISTERQUEUEREQUEST._serialized_start=25
  _REGISTERQUEUEREQUEST._serialized_end=66
  _REGISTERQUEUERESPONSE._serialized_start=68
  _REGISTERQUEUERESPONSE._serialized_end=110
  _REGISTEREXCHANGEREQUEST._serialized_start=112
  _REGISTEREXCHANGEREQUEST._serialized_end=216
  _REGISTEREXCHANGERESPONSE._serialized_start=218
  _REGISTEREXCHANGERESPONSE._serialized_end=263
  _QUEUEMESSAGEREQUEST._serialized_start=266
  _QUEUEMESSAGEREQUEST._serialized_end=422
  _QUEUEMESSAGERESPONSE._serialized_start=425
  _QUEUEMESSAGERESPONSE._serialized_end=562
  _QUEUEEVENT._serialized_start=564
  _QUEUEEVENT._serialized_end=691
  _UNREGISTERQUEUEREQUEST._serialized_start=693
  _UNREGISTERQUEUEREQUEST._serialized_end=736
  _UNREGISTERQUEUERESPONSE._serialized_start=738
  _UNREGISTERQUEUERESPONSE._serialized_end=763
# @@protoc_insertion_point(module_scope)
