# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: watch.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0bwatch.proto\x12\x07openiap\"5\n\x0cWatchRequest\x12\x16\n\x0e\x63ollectionname\x18\x01 \x01(\t\x12\r\n\x05paths\x18\x02 \x03(\t\"\x1b\n\rWatchResponse\x12\n\n\x02id\x18\x01 \x01(\t\"=\n\nWatchEvent\x12\n\n\x02id\x18\x01 \x01(\t\x12\x11\n\toperation\x18\x02 \x01(\t\x12\x10\n\x08\x64ocument\x18\x03 \x01(\t\"\x1c\n\x0eUnWatchRequest\x12\n\n\x02id\x18\x01 \x01(\t\"\x11\n\x0fUnWatchResponseb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'watch_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WATCHREQUEST._serialized_start=24
  _WATCHREQUEST._serialized_end=77
  _WATCHRESPONSE._serialized_start=79
  _WATCHRESPONSE._serialized_end=106
  _WATCHEVENT._serialized_start=108
  _WATCHEVENT._serialized_end=169
  _UNWATCHREQUEST._serialized_start=171
  _UNWATCHREQUEST._serialized_end=199
  _UNWATCHRESPONSE._serialized_start=201
  _UNWATCHRESPONSE._serialized_end=218
# @@protoc_insertion_point(module_scope)
